package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Objects;

/**
 * GitFileSource
 */
public class GitFileSource extends FileSource {
    @Nonnull private final String gitUrl;
    @Nullable private final String repoSubDir;
    @Nullable private final String branch;

    @Nullable private final String username;
    @Nullable private final String password;

    @Nullable private final String privateKeyPem;

    //name of the single file in the git repo we are interested in
    @Nullable private final String filename;

    public GitFileSource(@Nonnull  String gitUrl,
                         @Nullable String repoSubDir,
                         @Nullable String branch,
                         @Nullable String username,
                         @Nullable String password,
                         @Nullable String privateKeyPem,
                         @Nullable String filename) {
        super(SourceType.GIT, gitUrl, filename == null ? "git-repo" : filename);
        this.gitUrl = gitUrl;
        this.repoSubDir = repoSubDir;
        this.branch = branch;
        this.username = username;
        this.password = password;
        this.privateKeyPem = privateKeyPem;
        this.filename = filename;
    }

    @Nonnull
    public String getGitUrl() {
        return gitUrl;
    }

    @Nullable
    public String getRepoSubDir() {
        return repoSubDir;
    }

    @Nullable
    public String getBranch() {
        return branch;
    }

    @Nullable
    public String getUsername() {
        return username;
    }

    @Nullable
    public String getPassword() {
        return password;
    }

    @Nullable
    public String getPrivateKeyPem() {
        return privateKeyPem;
    }

    @Nullable
    public String getFilename() {
        return filename;
    }

    public boolean isFile() {
        return filename != null;
    }
    public boolean isDir() {
        return filename == null;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitFileSource that = (GitFileSource) o;
        return Objects.equals(gitUrl, that.gitUrl) &&
                Objects.equals(repoSubDir, that.repoSubDir) &&
                Objects.equals(branch, that.branch) &&
                Objects.equals(username, that.username) &&
                Objects.equals(password, that.password) &&
                Objects.equals(privateKeyPem, that.privateKeyPem) &&
                Objects.equals(filename, that.filename);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode(), gitUrl, repoSubDir, branch, username, password, privateKeyPem, filename);
    }

    @Override
    public String toString() {
        return "GitFileSource{" +
                "gitUrl='" + gitUrl + '\'' +
                (repoSubDir == null ? "" : ", repoSubDir='" + repoSubDir + '\'') +
                (branch == null ? "" : ", branch='" + branch + '\'') +
                (username == null ? "" : "username='" + username + '\'' )+
                (password == null ? "" : ", password='" + password + '\'') +
                (privateKeyPem == null ? "" : ", privateKeyPem='" + privateKeyPem + '\'') +
                (filename == null ? "" : ", filename='" + filename + '\'') +
                ", basename='" + basename + '\'' +
                '}';
    }
}
